package sun.util.locale;

import java.util.List;
import java.util.Map;
import java.util.Set;

public final class LocaleUtils
{
    private LocaleUtils() {
    }
    
    public static boolean caseIgnoreMatch(String s, String s2) {
        if (s == s2) {
            return true;
        }
        int length = s.length();
        if (length != s2.length()) {
            return false;
        }
        int i = 0;
        while (i < length) {
            int char1 = s.charAt(i);
            int char2 = s2.charAt(i);
            if (char1 != char2 && toLower((char)char1) != toLower((char)char2)) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    static int caseIgnoreCompare(String s, String s2) {
        if (s == s2) {
            return 0;
        }
        return toLowerString(s).compareTo(toLowerString(s2));
    }
    
    static char toUpper(char c) {
        return isLower(c) ? ((char)(c - 32)) : c;
    }
    
    static char toLower(char c) {
        return isUpper(c) ? ((char)(c + 32)) : c;
    }
    
    public static String toLowerString(String s) {
        int length;
        int index;
        for (length = s.length(), index = 0; index < length && !isUpper(s.charAt(index)); ++index) {}
        if (index == length) {
            return s;
        }
        char[] value = new char[length];
        for (int i = 0; i < length; ++i) {
            int char1 = s.charAt(i);
            value[i] = ((i < index) ? char1 : toLower((char)char1));
        }
        return new String(value);
    }
    
    static String toUpperString(String s) {
        int length;
        int index;
        for (length = s.length(), index = 0; index < length && !isLower(s.charAt(index)); ++index) {}
        if (index == length) {
            return s;
        }
        char[] value = new char[length];
        for (int i = 0; i < length; ++i) {
            int char1 = s.charAt(i);
            value[i] = ((i < index) ? char1 : toUpper((char)char1));
        }
        return new String(value);
    }
    
    static String toTitleString(String s) {
        int length;
        if ((length = s.length()) == 0) {
            return s;
        }
        int i = 0;
        if (!isLower(s.charAt(i))) {
            i = 1;
            while (i < length) {
                if (isUpper(s.charAt(i))) {
                    break;
                }
                ++i;
            }
        }
        if (i == length) {
            return s;
        }
        char[] value = new char[length];
        for (int j = 0; j < length; ++j) {
            int char1 = s.charAt(j);
            if (j == 0 && i == 0) {
                value[j] = toUpper((char)char1);
            }
            else if (j < i) {
                value[j] = char1;
            }
            else {
                value[j] = toLower((char)char1);
            }
        }
        return new String(value);
    }
    
    private static boolean isUpper(char c) {
        return c >= 'A' && c <= 'Z';
    }
    
    private static boolean isLower(char c) {
        return c >= 'a' && c <= 'z';
    }
    
    static boolean isAlpha(char c) {
        return (c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z');
    }
    
    static boolean isAlphaString(String s) {
        int length = s.length();
        int i = 0;
        while (i < length) {
            if (!isAlpha(s.charAt(i))) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    static boolean isNumeric(char c) {
        return c >= '0' && c <= '9';
    }
    
    static boolean isNumericString(String s) {
        int length = s.length();
        int i = 0;
        while (i < length) {
            if (!isNumeric(s.charAt(i))) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    static boolean isAlphaNumeric(char c) {
        return isAlpha(c) || isNumeric(c);
    }
    
    public static boolean isAlphaNumericString(String s) {
        int length = s.length();
        int i = 0;
        while (i < length) {
            if (!isAlphaNumeric(s.charAt(i))) {
                return false;
            }
            ++i;
        }
        return true;
    }
    
    static boolean isEmpty(String s) {
        return s == null || s.length() == 0;
    }
    
    static boolean isEmpty(Set<?> set) {
        return set == null || set.isEmpty();
    }
    
    static boolean isEmpty(Map<?, ?> map) {
        return map == null || map.isEmpty();
    }
    
    static boolean isEmpty(List<?> list) {
        return list == null || list.isEmpty();
    }
}
